package com.microservices.dms.achievementLibrary.mapper;

import java.util.List;

import com.microservices.common.datasource.annotation.Slave;
import com.microservices.dms.achievementLibrary.domain.AchievementTeam;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

/**
 * 成果团队Mapper接口
 * 
 * @author microservices
 * @date 2025-04-23
 */
@Mapper
@Slave
public interface AchievementTeamMapper 
{
    /**
     * 查询成果团队
     * 
     * @param id 成果团队主键
     * @return 成果团队
     */
    public AchievementTeam selectAchievementTeamById(Long id);

    /**
     * 查询成果团队列表
     * 
     * @param achievementTeam 成果团队
     * @return 成果团队集合
     */
    public List<AchievementTeam> selectAchievementTeamList(AchievementTeam achievementTeam);

    /**
     * 新增成果团队
     * 
     * @param achievementTeam 成果团队
     * @return 结果
     */
    public int insertAchievementTeam(AchievementTeam achievementTeam);

    /**
     * 修改成果团队
     * 
     * @param achievementTeam 成果团队
     * @return 结果
     */
    public int updateAchievementTeam(AchievementTeam achievementTeam);

    /**
     * 删除成果团队
     * 
     * @param id 成果团队主键
     * @return 结果
     */
    public int deleteAchievementTeamById(Long id);

    /**
     * 批量删除成果团队
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAchievementTeamByIds(Long[] ids);

    void deleteAchievementTeamByAId(@Param("aid") Long aid);
}
